import base64
import logging
import typing

import requests
from spacedork.reps.base import SearchBase

logger = logging.getLogger("dork")


class Fofa(SearchBase):
    URL = 'https://fofa.info/api/v1/search/all'

    def __init__(self, session: requests.session, token=None, limit=10, **kwargs):
        super().__init__(**kwargs)
        self.token = token
        self.client = session
        self.limit = limit
        self._total = 0

    @staticmethod
    def format_fofa(item: dict) -> typing.Dict:
        new_item = {
            "url": f'{item[0]}://{item[1]}:{item[2]}',
            "ip": item[1],
            "port": item[2],
        }
        return new_item

    def _query(self, dork: str, page: int) -> typing.Optional[typing.List[dict]]:
        resp = requests.Response()
        items = []
        for i in range(3):
            try:
                resp = self.client.get(self.URL, timeout=60,
                                       params={"qbase64": base64.b64encode(dork.encode()).decode(),
                                               "page": page, "key": self.token,
                                               "fields": "protocol,ip,port"})
                break
            except Exception as e:
                logger.debug(f"Req Error:{e} to continue")
                break
        if resp.status_code is None:
            return
        if resp and resp.status_code == 200:
            content = resp.json()
            if content["error"]:
                return
            try:
                total = content['size']
                self._total = total
            except Exception as e:
                logger.debug(e)
                return
            for match in content['results']:
                item = self.format_fofa(match)
                items.append(item)
            return items
        else:
            logger.debug(f"req Error:{resp}")


if __name__ == "__main__":
    fofa = Fofa("")
    fofa.query('')



import logging
import typing
import requests
from spacedork.reps.base import SearchBase

logger = logging.getLogger("dork")


def format_zoomeye(item):
    service = item['portinfo']['service']
    port = str(item['portinfo']['port'])
    new_item = {

        "port": port,
    }
    if isinstance(item["ip"], list):
        if item["ip"]:
            new_item["ip"] = item["ip"][0]
        else:
            new_item["ip"] = ""
    else:
        new_item["ip"] = item['ip']

    if "site" in item and item["site"]:
        new_item["url"] = f"{service}://{item['site']}"
    else:
        if "443" in port:
            new_item["url"] = f"{service}://{item['ip']}:{port}"
        else:
            new_item["url"] = f"{service}://{item['ip']}:{port}"
    if "country_name_CN" in item:
        new_item["country"] = item.pop("country_name_CN")
    if "subdivisions_name_CN" in item:
        new_item["city"] = item.pop("subdivisions_name_CN")
    return new_item


class ZoomEye(SearchBase):
    URL = 'https://api.zoomeye.org/search'

    def __init__(self, token, **kwargs):
        super().__init__(**kwargs)
        self.token = token
        self.resources = None
        self.client = requests.Session()
        self.client.headers = {'User-Agent': 'Python Zoomeye Client 3.0', 'API-KEY': token}
        self.total = -1

    def _query(self, dork: str, page, resource='host') -> typing.Optional[typing.List[dict]]:
        resp = requests.Response()
        for i in range(3):
            try:
                resp = self.client.get(self.URL, params={"query": dork, "page": page})
            except Exception as e:
                logger.debug(f"Req Error:{e}")
                return
        items = []
        if resp and resp.status_code == 200 and 'matches' in resp.text:
            content = resp.json()
            total = content['total']
            self.total = total
            for match in content['matches']:
                item = format_zoomeye(match)
                items.append(item)
            return items
        else:
            logger.warning(f"req Error:{resp}")


if __name__ == "__main__":
    zoomeye = ZoomEye("", fields="url")
    zoomeye.query('weblogic')



import argparse
import logging
import os

import requests
import yaml

from spacedork import reps, VERSION

logger = logging.getLogger("dork")
formatter = logging.Formatter('%(levelname)s - %(message)s')
console_handler = logging.StreamHandler()
console_handler.setFormatter(formatter)
logger.addHandler(console_handler)

home_directory = os.path.expanduser("~")
config_file_path = os.path.join(home_directory, ".config", 'spacedork', 'config.yaml')


def cmd_parser():
    parser = argparse.ArgumentParser(description='这是一个示例命令行参数解析程序')
    parser.add_argument('--list-module', required=False, help='列举所有模块', action='store_true')
    parser.add_argument('--config', '-c', required=False, help=f'配置文件路径({config_file_path})',
                        default=config_file_path)
    parser.add_argument('--dork', '-q', required=False, help='查询dork关键字')
    parser.add_argument('--module', '-m', required=False, default='zoomeye', help='使用查询模型')
    parser.add_argument('--start-page', type=int, default=1, help='要处理的数量')
    parser.add_argument('--end-page', type=int, default=1, help='要处理的数量')
    parser.add_argument('--thread', '-t', type=int, default=2, help='协程数')
    parser.add_argument('--fields', '-f', default="url", help='输出字段(url|ip|port|address)')
    parser.add_argument('-o', dest="output", default="", help='保存为文件')
    parser.add_argument('-v', dest="version", default=False, action='store_true', help='Version')
    parser.add_argument('-debug', default=False, action='store_true', help='DEBUG')
    args = parser.parse_args()
    if args.debug:
        logger.setLevel(logging.DEBUG)
    if args.version:
        print(VERSION)
        exit()
    if args.fields not in ("url", "ip", "port", "address"):
        print("请选择输出字段(url|ip|port)")
        exit()
    if args.list_module:
        for k, v in reps.repo.items():
            print(k)
        exit()
    elif not args.dork:
        print("请提供dork关键字")
        exit()
    if not os.path.exists(args.config):
        print("配置文件不存在:{}".format(args.config))
        exit()
    return args


def main():
    args = cmd_parser()
    with open(args.config, "r") as yaml_file:
        try:
            yaml_data = yaml.safe_load(yaml_file)
        except yaml.YAMLError as e:
            logger.error(f"YAML解析错误: {e}")
            return
    plugin = reps.repo.get(args.module)
    plugin_options = yaml_data.get(args.module, {})
    client = requests.Session()
    cls = plugin(client, **plugin_options, fields=args.fields)
    if args.output:
        with open(args.output, 'w') as f:
            for x in cls.query(args.dork, start_page=args.start_page, end_page=args.end_page):
                f.write(x[args.fields] + "\n")
    else:
        for i in cls.query(args.dork, start_page=args.start_page, end_page=args.end_page):
            print(i[args.fields])
    logger.info("Search DONE")


if __name__ == '__main__':
    main()



import logging
import typing

logger = logging.getLogger("dork")


class SearchBase(object):
    def __init__(self, fields="url", **kwargs):
        self.fields = fields

    def _query(self, dork: str, page: int) -> typing.Optional[typing.List[dict]]:
        ...

    def query(self, dork: str, start_page=1, end_page=1) -> typing.Iterable[typing.Dict]:
        current_page = 1
        while True:
            items = self._query(dork, page=current_page)
            if not items:
                break
            for item in items:
                yield item
            if current_page >= end_page:
                break
